tlslite.utils.cipherfactory

Package tlslite :: Package utils :: Module cipherfactory |
[hide private]
[frames] | no frames]

# Module cipherfactory

source code

Factory functions for symmetric cryptography.

Functions | [hide private]
tlslite.utils.AES |
createAES(key, IV, implList=None) Create a new AES object. | source code
tlslite.utils.RC4 |
createRC4(key, IV, implList=None) Create a new RC4 object. | source code
tlslite.utils.TripleDES |
createTripleDES(key, IV, implList=None) Create a new 3DES object. | source code

Variables | [hide private]
| __package__ = ``'``tlslite.utils``'``
| tripleDESPresent = `True`

Function Details | [hide private]

### createAES(key, IV, implList=None) | source code
Create a new AES object. Parameters: `key` (str) - A 16, 24, or 32 byte string. `IV` (str) - A 16 byte string Returns: tlslite.utils.AES An AES object.

### createRC4(key, IV, implList=None) | source code
Create a new RC4 object. Parameters: `key` (str) - A 16 to 32 byte string. `IV` (object) - Ignored, whatever it is. Returns: tlslite.utils.RC4 An RC4 object.

### createTripleDES(key, IV, implList=None) | source code
Create a new 3DES object. Parameters: `key` (str) - A 24 byte string. `IV` (str) - An 8 byte string Returns: tlslite.utils.TripleDES A 3DES object.